@@ -13,21 +13,22 @@ import typing
 import zipfile
 import zlib
 from collections.abc import Callable, Generator
-from pathlib import Path
-from typing import Any, Literal
+from typing import Literal
 
 import boto3
 import fsspec
 import fsspec.utils
-from cloudpathlib import CloudPath, S3Client, S3Path
+from iker.common.utils.jsonutils import JsonObject
 from iker.common.utils.sequtils import chunk_between, head, last
 from iker.common.utils.shutils import glob_match, listfile, path_depth
 from iker.common.utils.strutils import is_empty, trim_to_none
-from rich.progress import BarColumn, DownloadColumn, Progress, TaskID, TextColumn, TransferSpeedColumn
+from mypy_boto3_s3 import S3Client
+from rich.progress import BarColumn, DownloadColumn, Progress, TextColumn, TransferSpeedColumn
 
 __all__ = [
     "S3ObjectMeta",
     "s3_make_client",
+    "s3_head_object",
     "s3_list_objects",
     "s3_listfile",
     "s3_cp_download",
@@ -36,12 +37,13 @@ __all__ = [
     "s3_sync_upload",
     "s3_pull_text",
     "s3_push_text",
-    "S3TransferCallbackClient",
-    "s3_make_progress_callback",
     "s3_make_progressed_client",
+    "ArchiveMemberChunk",
     "s3_archive_member_tree",
     "s3_archive_listfile",
     "s3_archive_open_member",
+    "s3_archive_use_ranged_requests",
+    "s3_archive_use_chunked_reads",
     "s3_archive_open_members",
 ]
 
@@ -81,12 +83,29 @@ def s3_make_client(
     session = boto3.Session(aws_access_key_id=trim_to_none(access_key_id),
                             aws_secret_access_key=trim_to_none(secret_access_key),
                             region_name=trim_to_none(region_name))
-    client = S3Client(boto3_session=session, endpoint_url=trim_to_none(endpoint_url))
+    client = session.client("s3", endpoint_url=trim_to_none(endpoint_url))
+    client.meta.credentials = session.get_credentials()
     try:
         yield client
     finally:
-        if hasattr(client, "close"):
-            client.close()
+        client.close()
+
+
+def s3_head_object(
+    client: S3Client,
+    bucket: str,
+    key: str,
+) -> S3ObjectMeta:
+    """
+    Retrieves metadata of an object from the given S3 ``bucket`` and ``key``.
+
+    :param client: An instance of ``S3Client``.
+    :param bucket: Bucket name.
+    :param key: Object key.
+    :return: An ``S3ObjectMeta`` object representing the S3 object.
+    """
+    response = client.head_object(Bucket=bucket, Key=key)
+    return S3ObjectMeta(key=key, last_modified=response["LastModified"], size=response["ContentLength"])
 
 
 def s3_list_objects(
@@ -108,12 +127,12 @@ def s3_list_objects(
     count = 0
     while True:
         if is_empty(continuation_token):
-            response = client.client.list_objects_v2(MaxKeys=1000, Bucket=bucket, Prefix=prefix)
+            response = client.list_objects_v2(MaxKeys=1000, Bucket=bucket, Prefix=prefix)
         else:
-            response = client.client.list_objects_v2(MaxKeys=1000,
-                                                     Bucket=bucket,
-                                                     Prefix=prefix,
-                                                     ContinuationToken=continuation_token)
+            response = client.list_objects_v2(MaxKeys=1000,
+                                              Bucket=bucket,
+                                              Prefix=prefix,
+                                              ContinuationToken=continuation_token)
 
         contents = response.get("Contents", [])
         count += len(contents)
@@ -172,7 +191,7 @@ def s3_cp_download(client: S3Client, bucket: str, key: str, file_path: str | os.
     :param key: Object key.
     :param file_path: Local file path to save the object.
     """
-    client.client.download_file(bucket, key, file_path)
+    client.download_file(bucket, key, file_path)
 
 
 def s3_cp_upload(client: S3Client, file_path: str | os.PathLike[str], bucket: str, key: str):
@@ -185,10 +204,10 @@ def s3_cp_upload(client: S3Client, file_path: str | os.PathLike[str], bucket: st
     :param key: Object key for the uploaded file.
     """
     t, _ = mimetypes.MimeTypes().guess_type(file_path)
-    client.client.upload_file(file_path,
-                              bucket,
-                              key,
-                              ExtraArgs={"ContentType": "binary/octet-stream" if t is None else t})
+    client.upload_file(file_path,
+                       bucket,
+                       key,
+                       ExtraArgs={"ContentType": "binary/octet-stream" if t is None else t})
 
 
 def s3_sync_download(
@@ -308,7 +327,7 @@ def s3_pull_text(client: S3Client, bucket: str, key: str, encoding: str = None)
     :return: The decoded text content.
     """
     with tempfile.TemporaryFile() as fp:
-        client.client.download_fileobj(bucket, key, fp)
+        client.download_fileobj(bucket, key, fp)
         fp.seek(0)
         return fp.read().decode(encoding or "utf-8")
 
@@ -326,95 +345,111 @@ def s3_push_text(client: S3Client, text: str, bucket: str, key: str, encoding: s
     with tempfile.TemporaryFile() as fp:
         fp.write(text.encode(encoding or "utf-8"))
         fp.seek(0)
-        client.client.upload_fileobj(fp, bucket, key)
+        client.upload_fileobj(fp, bucket, key)
 
 
-TransferDirection = Literal["download", "upload"]
-TransferState = Literal["start", "update", "stop"]
+class S3ClientProgressProxy(object):
+    def __init__(self, client: S3Client, progress: Progress):
+        self.client = client
+        self.progress = progress
 
+    @contextlib.contextmanager
+    def make_transfer_callback(self, key: str, bytes_total: int, direction: Literal["download", "upload"]):
+        task_id = self.progress.add_task(direction, total=bytes_total, key=key)
+        try:
+            yield lambda bytes_sent: self.progress.update(task_id, advance=bytes_sent)
+        finally:
+            self.progress.remove_task(task_id)
 
-@contextlib.contextmanager
-def make_transfer_callback(
-    callback: Callable[[CloudPath, TransferDirection, TransferState, int], None],
-    path: Path | CloudPath,
-    direction: TransferDirection,
-):
-    if callback is None:
-        yield None
-        return
+    def __getattr__(self, name):
+        return getattr(self.client, name)
 
-    callback(path, direction, "start", 0)
-    try:
-        yield functools.partial(callback, path, direction, "update")
-    finally:
-        callback(path, direction, "stop", 0)
-
-
-class S3TransferCallbackClient(S3Client):
-    def __init__(
+    def download_file(
         self,
-        *args,
-        transfer_callback: Callable[[Path | CloudPath, TransferDirection, TransferState, int], None],
-        **kwargs,
+        Bucket,
+        Key,
+        Filename,
+        ExtraArgs=None,
+        Callback=None,
+        Config=None,
     ):
-        super().__init__(*args, **kwargs)
-        self.transfer_callback = transfer_callback
+        object_meta = s3_head_object(self.client, Bucket, Key)
+        with (
+            contextlib.nullcontext(Callback) if Callback is not None
+            else self.make_transfer_callback(Key, object_meta.size, "download")
+        ) as callback:
+            return self.client.download_file(Bucket,
+                                             Key,
+                                             Filename,
+                                             ExtraArgs=ExtraArgs,
+                                             Callback=callback,
+                                             Config=Config)
 
-    def _download_file(self, cloud_path: S3Path, local_path: str | os.PathLike[str]) -> Path:
-        local_path = Path(local_path)
+    def download_fileobj(
+        self,
+        Bucket,
+        Key,
+        Fileobj,
+        ExtraArgs=None,
+        Callback=None,
+        Config=None,
+    ):
+        object_meta = s3_head_object(self.client, Bucket, Key)
+        with (
+            contextlib.nullcontext(Callback) if Callback is not None
+            else self.make_transfer_callback(Key, object_meta.size, "download")
+        ) as callback:
+            return self.client.download_fileobj(Bucket,
+                                                Key,
+                                                Fileobj,
+                                                ExtraArgs=ExtraArgs,
+                                                Callback=callback,
+                                                Config=Config)
 
-        obj = self.s3.Object(cloud_path.bucket, cloud_path.key)
+    def upload_file(
+        self,
+        Filename,
+        Bucket,
+        Key,
+        ExtraArgs=None,
+        Callback=None,
+        Config=None,
+    ):
+        bytes_total = os.path.getsize(Filename)
+        with (
+            contextlib.nullcontext(Callback) if Callback is not None
+            else self.make_transfer_callback(Key, bytes_total, "upload")
+        ) as callback:
+            return self.client.upload_file(Filename,
+                                           Bucket,
+                                           Key,
+                                           ExtraArgs=ExtraArgs,
+                                           Callback=callback,
+                                           Config=Config)
 
-        with make_transfer_callback(self.transfer_callback, cloud_path, "download") as callback:
-            obj.download_file(
-                str(local_path),
-                Config=self.boto3_transfer_config,
-                ExtraArgs=self.boto3_dl_extra_args,
-                Callback=callback,
-            )
-        return local_path
-
-    def _upload_file(self, local_path: str | os.PathLike[str], cloud_path: S3Path) -> S3Path:
-        local_path = Path(local_path)
-
-        obj = self.s3.Object(cloud_path.bucket, cloud_path.key)
-
-        extra_args = self.boto3_ul_extra_args.copy()
-
-        if self.content_type_method is not None:
-            content_type, content_encoding = self.content_type_method(str(local_path))
-            if content_type is not None:
-                extra_args["ContentType"] = content_type
-            if content_encoding is not None:
-                extra_args["ContentEncoding"] = content_encoding
-
-        with make_transfer_callback(self.transfer_callback, local_path, "upload") as callback:
-            obj.upload_file(
-                str(local_path),
-                Config=self.boto3_transfer_config,
-                ExtraArgs=extra_args,
-                Callback=callback,
-            )
-        return cloud_path
-
-
-def s3_make_progress_callback(
-    progress: Progress,
-) -> Callable[[Path | CloudPath, TransferDirection, TransferState, int], None]:
-    task_ids: dict[Path | CloudPath, TaskID] = {}
-
-    def progress_callback(path: Path | CloudPath, direction: TransferDirection, state: TransferState, bytes_sent: int):
-        if state == "start":
-            size = path.stat().st_size
-            task_ids[path] = progress.add_task(direction, total=size, filename=path.name)
-        elif state == "stop":
-            if path in task_ids:
-                progress.remove_task(task_ids[path])
-                del task_ids[path]
-        else:
-            progress.update(task_ids[path], advance=bytes_sent)
-
-    return progress_callback
+    def upload_fileobj(
+        self,
+        Fileobj,
+        Bucket,
+        Key,
+        ExtraArgs=None,
+        Callback=None,
+        Config=None,
+    ):
+        current_pos = Fileobj.tell()
+        Fileobj.seek(0, os.SEEK_END)
+        bytes_total = Fileobj.tell() - current_pos
+        Fileobj.seek(current_pos)
+        with (
+            contextlib.nullcontext(Callback) if Callback is not None
+            else self.make_transfer_callback(Key, bytes_total, "upload")
+        ) as callback:
+            return self.client.upload_fileobj(Fileobj,
+                                              Bucket,
+                                              Key,
+                                              ExtraArgs=ExtraArgs,
+                                              Callback=callback,
+                                              Config=Config)
 
 
 if typing.TYPE_CHECKING:
@@ -432,43 +467,49 @@ def s3_make_progressed_client(
     secret_access_key: str = None,
     region_name: str = None,
     endpoint_url: str = None,
-) -> Generator[S3Client, None, None]:
+) -> Generator[S3ClientProgressProxy, None, None]:
     """
-    Creates an S3 client with progress callback as a context manager for safe resource handling.
+    Creates an S3 client with progress reporting as a context manager.
 
     :param access_key_id: AWS access key ID.
     :param secret_access_key: AWS secret access key.
     :param region_name: AWS service region name.
     :param endpoint_url: AWS service endpoint URL.
-    :return: An instance of ``S3TransferCallbackClient``.
+    :return: An instance of ``S3ClientProgressProxy`` that wraps an ``S3Client`` with progress reporting.
     """
     with Progress(
-        TextColumn("[blue]{task.fields[filename]}"),
+        TextColumn("[blue]{task.fields[key]}"),
         BarColumn(),
         DownloadColumn(),
         TransferSpeedColumn(),
     ) as progress:
-        session = boto3.Session(aws_access_key_id=trim_to_none(access_key_id),
-                                aws_secret_access_key=trim_to_none(secret_access_key),
-                                region_name=trim_to_none(region_name))
-        yield S3TransferCallbackClient(boto3_session=session,
-                                       endpoint_url=trim_to_none(endpoint_url),
-                                       transfer_callback=s3_make_progress_callback(progress))
+        with s3_make_client(access_key_id, secret_access_key, region_name, endpoint_url) as client:
+            yield S3ClientProgressProxy(client, progress)
 
 
-def s3_options_from_s3_client(client: S3Client) -> dict[str, Any]:
+def s3_options_from_s3_client(client: S3Client) -> JsonObject:
     """
     Extracts S3 connection options from an existing S3Client instance for use with ``fsspec``.
 
     :param client: An instance of ``S3Client``.
     :return: A dictionary of S3 connection options.
     """
-    if client.sess is None:
+    if client is None:
         return {}
 
-    s3_options: dict[str, Any] = {}
+    s3_options: JsonObject = {}
 
-    credentials = client.sess.get_credentials()
+    try:
+        # Extract credentials from the client
+        # First try the public meta attribute, which is injected by our `s3_make_client` function, if available
+        credentials = client.meta.credentials
+    except AttributeError:
+        try:
+            # Fallback to private attribute (may not be stable across boto3 versions)
+            credentials = client._request_signer._credentials
+        except AttributeError:
+            # Unable to extract credentials
+            raise AttributeError("cannot extract credentials from the provided S3Client instance")
     if credentials is not None:
         if credentials.access_key:
             s3_options["key"] = credentials.access_key
@@ -478,10 +519,10 @@ def s3_options_from_s3_client(client: S3Client) -> dict[str, Any]:
             s3_options["token"] = credentials.token
 
     client_kwargs = {}
-    if client.sess.region_name or client.client.meta.region_name:
-        client_kwargs["region_name"] = client.sess.region_name or client.client.meta.region_name
-    if client.client.meta.endpoint_url:
-        client_kwargs["endpoint_url"] = client.client.meta.endpoint_url
+    if client.meta.region_name:
+        client_kwargs["region_name"] = client.meta.region_name
+    if client.meta.endpoint_url:
+        client_kwargs["endpoint_url"] = client.meta.endpoint_url
 
     if client_kwargs:
         s3_options["client_kwargs"] = client_kwargs
@@ -658,17 +699,86 @@ def s3_archive_open_member(
         yield s3_fh
 
 
-ZIPFILE_HEADER_MIN_SIZE = 30
-ZIPFILE_HEADER_FN_LEN_OFFSET = 26
-ZIPFILE_HEADER_EX_LEN_OFFSET = 28
+ZIP_CENTRAL_DIR_ESTIMATED_SIZE = 64 * 1024
+ZIP_INFO_HDR_MIN_SIZE = 30
+ZIP_INFO_HDR_ESTIMATED_SIZE = 128
+ZIP_INFO_HDR_FN_LEN_OFFSET = 26
+ZIP_INFO_HDR_EX_LEN_OFFSET = 28
 
 
-def zipfile_hdr_fn_len_slice(offset: int) -> slice:
-    return slice(offset + ZIPFILE_HEADER_FN_LEN_OFFSET, offset + ZIPFILE_HEADER_FN_LEN_OFFSET + 2)
+@dataclasses.dataclass(frozen=True)
+class ArchiveMemberChunk(object):
+    name: str
+    header_offset: int
+    compress_size: int
+    compress_type: int
+    header_overhead: int = ZIP_INFO_HDR_ESTIMATED_SIZE
+
+    @property
+    def begin(self) -> int:
+        return self.header_offset
+
+    @property
+    def end(self) -> int:
+        return self.header_offset + self.header_overhead + self.compress_size
 
 
-def zipfile_hdr_ex_len_slice(offset: int) -> slice:
-    return slice(offset + ZIPFILE_HEADER_EX_LEN_OFFSET, offset + ZIPFILE_HEADER_EX_LEN_OFFSET + 2)
+def s3_archive_use_ranged_requests(
+    threshold: float = 0.5,
+    central_directory_overhead: int = 64 * ZIP_CENTRAL_DIR_ESTIMATED_SIZE,
+    zip_info_header_overhead: int = ZIP_INFO_HDR_ESTIMATED_SIZE,
+) -> Callable[[int, list[zipfile.ZipInfo]], bool]:
+    """
+    Decide whether to use ranged requests for accessing members of a ZIP archive in S3
+    based on estimated transfer size ratio.
+
+    :param threshold: If (estimated ranged transfer bytes / archive bytes) <= threshold, use ranged per-member access;
+                      otherwise download the whole archive.
+    :param central_directory_overhead: Estimated overhead size for the central directory in bytes.
+    :param zip_info_header_overhead: Estimated overhead size for each member's ``ZipInfo`` header in bytes.
+    :return: A callable that takes (``archive_size``, ``member_zip_infos``) and returns a boolean
+             indicating whether to use ranged requests.
+    """
+
+    if zip_info_header_overhead < ZIP_INFO_HDR_MIN_SIZE:
+        raise ValueError(f"zip_info_header_overhead must be at least {ZIP_INFO_HDR_MIN_SIZE} bytes")
+
+    def use_ranged_requests(
+        archive_size: int,
+        member_zip_infos: list[zipfile.ZipInfo],
+    ) -> bool:
+        estimated_ranged_total_size = central_directory_overhead + sum(info.compress_size + zip_info_header_overhead
+                                                                       for info in member_zip_infos)
+
+        # Avoid division by zero; prefer ranged if archive size is zero (degenerate case)
+        return (estimated_ranged_total_size / archive_size) <= threshold if archive_size > 0 else True
+
+    return use_ranged_requests
+
+
+def s3_archive_use_chunked_reads(
+    zip_info_header_overhead: int = ZIP_INFO_HDR_ESTIMATED_SIZE,
+) -> Callable[[zipfile.ZipInfo], ArchiveMemberChunk]:
+    """
+    Map each ``ZipInfo`` to an ``ArchiveMemberChunk`` for grouping adjacent members into single ranged reads.
+
+    :param zip_info_header_overhead: Estimated overhead size for each member's ``ZipInfo`` header in bytes.
+    :return: A callable that takes a ``ZipInfo`` and returns an ``ArchiveMemberChunk``.
+    """
+
+    if zip_info_header_overhead < ZIP_INFO_HDR_MIN_SIZE:
+        raise ValueError(f"zip_info_header_overhead must be at least {ZIP_INFO_HDR_MIN_SIZE} bytes")
+
+    def use_chunked_reads(
+        zip_info: zipfile.ZipInfo,
+    ) -> ArchiveMemberChunk:
+        return ArchiveMemberChunk(zip_info.filename,
+                                  zip_info.header_offset,
+                                  zip_info.compress_size,
+                                  zip_info.compress_type,
+                                  header_overhead=zip_info_header_overhead)
+
+    return use_chunked_reads
 
 
 def s3_archive_open_members(
@@ -678,10 +788,8 @@ def s3_archive_open_members(
     members: list[str] | None = None,
     mode: Literal["r", "rb"] = "r",
     *,
-    threshold: float = 0.5,
-    central_directory_overhead: int = 64 * 1024,
-    member_header_overhead: int = 128,
-    use_chunked_reads: bool = False,
+    use_ranged_requests: bool | Callable[[int, list[zipfile.ZipInfo]], bool] = True,
+    use_chunked_reads: bool | Callable[[zipfile.ZipInfo], ArchiveMemberChunk] = False,
 ) -> Generator[tuple[str, Callable[[], typing.IO]], None, None]:
     """
     Choose the best transfer strategy (ranged requests per-member vs full archive transfer)
@@ -712,44 +820,30 @@ def s3_archive_open_members(
     :param key: Object key of the ZIP archive.
     :param members: List of member names to stream.
     :param mode: File mode for opening members ("r" for text, "rb" for binary).
-    :param threshold: If (estimated ranged transfer bytes / archive bytes) <= threshold,
-                      use ranged per-member access; otherwise download the whole archive.
-    :param central_directory_overhead: Passed to s3_estimate_archive_ranged_requests.
-    :param member_header_overhead: Passed to s3_estimate_archive_ranged_requests.
-    :param use_chunked_reads: If ``True`` and ranged access is chosen, group adjacent members into single ranged reads.
+    :param use_ranged_requests: If ``True``, always use ranged requests to access the archive; if callable, use it as
+                                custom logic to decide based on the archive size and member infos; if ``False``, always
+                                download the whole archive.
+    :param use_chunked_reads: If ``True``, group adjacent members into single ranged reads using default ``ZipInfo``
+                              to ``ArchiveMemberChunk`` mapping; if callable, use it as custom mapping from
+                              ``ZipInfo`` to ``ArchiveMemberChunk`` for grouping adjacent members; if ``False``,
+                              read each member with individual ranged requests. If ``use_ranged_requests`` is ``False``,
+                              this parameter is ignored.
 
     :return: An iterable of callables that return file-like objects for each requested member.
     """
     if mode not in ("r", "rb"):
         raise ValueError("mode must be either 'r' or 'rb'")
-    if member_header_overhead < ZIPFILE_HEADER_MIN_SIZE:
-        raise ValueError(f"member_header_overhead must be at least {ZIPFILE_HEADER_MIN_SIZE} bytes")
 
     s3_options = s3_options_from_s3_client(client)
 
     archive_size, member_zip_infos, missed_members = s3_archive_listfile(client, bucket, key, members)
+    if missed_members:
+        raise FileNotFoundError(f"Archive members not found: {', '.join(missed_members)}")
 
-    if len(missed_members) > 0:
-        raise FileNotFoundError(f"members not found in archive '{missed_members}'")
+    if callable(use_ranged_requests):
+        use_ranged_requests = use_ranged_requests(archive_size, member_zip_infos)
 
-    estimated_ranged_total_size = central_directory_overhead + sum(info.compress_size + member_header_overhead
-                                                                   for info in member_zip_infos)
-
-    # Avoid division by zero; prefer ranged if archive size is zero (degenerate case)
-    use_ranged = (estimated_ranged_total_size / archive_size) <= threshold if archive_size > 0 else True
-
-    @dataclasses.dataclass(frozen=True)
-    class MemberChunk(object):
-        name: str
-        header_offset: int
-        compress_size: int
-        compress_type: int
-
-        @property
-        def end(self) -> int:
-            return self.header_offset + self.compress_size + member_header_overhead
-
-    if use_ranged and not use_chunked_reads:
+    if use_ranged_requests and not use_chunked_reads:
         for info in member_zip_infos:
             opener = functools.partial(s3_archive_open_member, client, bucket, key, info.filename, mode)
             yield info.filename, opener
@@ -757,17 +851,23 @@ def s3_archive_open_members(
 
     archive_url = f"s3://{bucket}/{key}"
 
-    if use_ranged and use_chunked_reads:
+    if use_ranged_requests and use_chunked_reads:
+
+        fn_len_slice = lambda index: slice(index + ZIP_INFO_HDR_FN_LEN_OFFSET, index + ZIP_INFO_HDR_FN_LEN_OFFSET + 2)
+        ex_len_slice = lambda index: slice(index + ZIP_INFO_HDR_EX_LEN_OFFSET, index + ZIP_INFO_HDR_EX_LEN_OFFSET + 2)
+
         # Open archive once to read central directory and gather ZipInfo for requested members.
         # We will group adjacent members (by local header offsets) and issue one ranged read per group,
         # then extract each member from the group's bytes to avoid many small ranged requests.
         with fsspec.open(archive_url, "rb", s3=s3_options) as s3_fh, zipfile.ZipFile(s3_fh) as archive:
+            if callable(use_chunked_reads):
+                chunks = [use_chunked_reads(info) for info in member_zip_infos]
+            else:
+                chunks = [ArchiveMemberChunk(info.filename, info.header_offset, info.compress_size, info.compress_type)
+                          for info in member_zip_infos]
 
-            chunks = [MemberChunk(info.filename, info.header_offset, info.compress_size, info.compress_type)
-                      for info in member_zip_infos]
-
-            chunks_groups = chunk_between(sorted(chunks, key=lambda x: x.header_offset),
-                                          chunk_func=lambda x, y: y.header_offset > x.end + member_header_overhead)
+            chunks_groups = chunk_between(sorted(chunks, key=lambda x: x.begin),
+                                          chunk_func=lambda x, y: y.begin > x.end)
 
             # For each group, create openers for members inside the group.
             for group in chunks_groups:
@@ -778,18 +878,18 @@ def s3_archive_open_members(
                 s3_fh.seek(group_offset)
                 group_bytes = s3_fh.read(group_size)
 
-                def make_opener(chunk: MemberChunk) -> Callable[[], typing.IO]:
+                def make_opener(chunk: ArchiveMemberChunk) -> Callable[[], typing.IO]:
 
                     def opener() -> typing.IO:
                         index = chunk.header_offset - group_offset
 
-                        if index + ZIPFILE_HEADER_MIN_SIZE > len(group_bytes):
+                        if index + ZIP_INFO_HDR_MIN_SIZE > len(group_bytes):
                             raise IOError("unexpected short read of member header")
 
-                        fn_len = int.from_bytes(group_bytes[zipfile_hdr_fn_len_slice(index)], "little")
-                        ex_len = int.from_bytes(group_bytes[zipfile_hdr_ex_len_slice(index)], "little")
+                        fn_len = int.from_bytes(group_bytes[fn_len_slice(index)], "little")
+                        ex_len = int.from_bytes(group_bytes[ex_len_slice(index)], "little")
 
-                        raw_data_begin = index + ZIPFILE_HEADER_MIN_SIZE + fn_len + ex_len
+                        raw_data_begin = index + ZIP_INFO_HDR_MIN_SIZE + fn_len + ex_len
                         raw_data_end = raw_data_begin + chunk.compress_size
 
                         if raw_data_end > len(group_bytes):
